/*
 * LINK framework for Java 1.7
 * LINK is an experimental lightweight framework which aims to increase the likelyhood of
 * producing correct applications. This is achieved by forming computation chains,
 * inspired by Floyd-Hoare and Propositional Logic, in which resulting system can be viewed as a formalized state machine.
 * LINK supports "Throwable" execution flow, Recursion, Computation refinement,
 * Computation retries for timing and intermittent issues.

 * Copyright (C) 2013  Aran Hakki (MEng Systems Engineering, University of Warwick)

 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.


 * If you are interested in this software and have any questions please feel free to contact:

 * Aran Hakki
 * MEng Systems Engineering
 * University of Warwick

 * Email: aran.hakki@gmail.com
 * Mob: 07824098949
 * Linkedin: http://uk.linkedin.com/in/aranhakki
 */

package link.common;

public class ExclusiveOR {

	private PropositionXOR[] propositions;
	
	public ExclusiveOR(PropositionXOR... props){
		propositions = props;
		for (PropositionXOR p : propositions){
			p.xor = this;
		}
		
		if (Config.isInTestMode){
			checkSoundnessAndCompleteness();
		}
		
	}
	
	private void checkSoundnessAndCompleteness() {
		int matches = 0;
		for (PropositionXOR p : propositions){
			if (p.eval()){
				matches++;
			}
		}
		
		if (matches==1){
			
		} else if (matches==0){
			throw new IllegalStateException("no match => not COMPLETE");
		} else {
			throw new IllegalStateException("more than one match => not SOUND");
		}
	}

}
