/*
 * LINK framework for Java 1.7
 * LINK is an experimental lightweight framework which aims to increase the likelyhood of
 * producing correct applications. This is achieved by forming computation chains,
 * inspired by Floyd-Hoare and Propositional Logic, in which resulting system can be viewed as a formalized state machine.
 * LINK supports "Throwable" execution flow, Recursion, Computation refinement,
 * Computation retries for timing and intermittent issues.

 * Copyright (C) 2013  Aran Hakki (MEng Systems Engineering, University of Warwick)

 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.


 * If you are interested in this software and have any questions please feel free to contact:

 * Aran Hakki
 * MEng Systems Engineering
 * University of Warwick

 * Email: aran.hakki@gmail.com
 * Mob: 07824098949
 * Linkedin: http://uk.linkedin.com/in/aranhakki
 */

package link.common.test;

import static link.common.Utils.propose;
import link.common.ExclusiveOR;
import link.common.Machine;
import link.common.PropositionXOR;
import link.common.ThrowableXOR;

public class TestMachine extends Machine<IntegerBaseState>{



	@Override
	protected void main(Object o) {
		
		propose(state.x==10,"x equals 10");
		
		try {
			String a = null;
			a.toString();
		} catch (Exception e){
			state.lastCaughtThrowable=e;
		}
		
		PropositionXOR xIs1 = new PropositionXOR(){

			@Override
			public
			boolean eval() {
				return state.x==1;
			}
			
		};
		
		PropositionXOR xIs2 = new PropositionXOR(){

			@Override
			public
			boolean eval() {
				return state.x==2;
			}
			
		};
		
		PropositionXOR xIs3 = new PropositionXOR(){

			@Override
			public
			boolean eval() {
				return state.x==3;
			}
			
		};
		
		ThrowableXOR t1 = new ThrowableXOR(NPEext.class,state);
		
		ExclusiveOR xor = new ExclusiveOR(xIs1,xIs2,xIs3,t1);
		
		if (xIs1.eval()){
			System.out.println("x=1");
		} else if (xIs2.eval()){
			System.out.println("x=2");
		} else if (xIs3.eval()){
			System.out.println("x=3");
		} else if (t1.eval()){
			System.out.println("NPEext");
		}
	}

	@Override
	protected IntegerBaseState getBaseState() {
		return new IntegerBaseState();
	}
	
	class NPEext extends NullPointerException {}

}
